@@ -1,4 +1,4 @@
-# Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
+# Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,7 +10,7 @@ package Devel::Cover::DB;
 use strict;
 use warnings;
 
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.29'; # VERSION
 
 use Devel::Cover::Criterion;
 use Devel::Cover::DB::File;
@@ -18,11 +18,12 @@ use Devel::Cover::DB::Structure;
 use Devel::Cover::DB::IO;
 
 use Carp;
+use File::Find;
 use File::Path;
 
 use Devel::Cover::Dumper;  # For debugging
 
-my $DB = "cover.14";  # Version of the database.
+my $DB = "cover.14";  # Version of the database
 
 @Devel::Cover::DB::Criteria =
     (qw( statement branch path condition subroutine pod time ));
@@ -103,6 +104,7 @@ sub write {
     unless (mkdir $self->{db}) {
         croak "Can't mkdir $self->{db}: $!\n" unless -d $self->{db};
     }
+    chmod 0777, $self->{db} if $self->{loose_perms};
     $self->validate_db;
 
     my $db = { runs => $self->{runs} };
@@ -132,6 +134,16 @@ sub delete {
     $self
 }
 
+sub clean {
+    my $self = shift;
+
+    # remove all lock files
+    my $rm_lock = sub {
+        unlink if /\.lock$/
+    };
+    find($rm_lock, $self->{db});
+}
+
 sub merge_runs {
     my $self = shift;
     my $db = $self->{db};
@@ -168,6 +180,8 @@ sub merge_runs {
         $st->write($self->{base});
     }
 
+    $self->clean;
+
     $self
 }
 
@@ -198,7 +212,7 @@ sub is_valid {
     opendir my $fh, $self->{db} or return 0;
     for my $file (readdir $fh) {
         next if $file eq "." || $file eq "..";
-        next if $file =~ /(?:runs|structure|debuglog|digests)$/
+        next if $file =~ /(?:runs|structure|debuglog|digests)|(?:\.lock)$/
                 && -e "$self->{db}/$file";
         warn "found $file in $self->{db}";
         return 0;
@@ -251,7 +265,7 @@ sub merge {
     return $self;  # TODO - what's going on here?
 
     # When the database gets big, it's quicker to merge into what's
-    # already there.
+    # already there
 
     _merge_hash($from->{runs},      $self->{runs});
     _merge_hash($from->{collected}, $self->{collected});
@@ -550,7 +564,7 @@ sub uncoverable {
     }
 
     # print STDERR Dumper $u;
-    # Now change the format of the uncoverable information.
+    # Now change the format of the uncoverable information
 
     for my $file (sort keys %$u) {
         # print STDERR "Reading $file\n";
@@ -576,7 +590,7 @@ sub uncoverable {
                     # print STDERR
                     # "Found uncoverable $file:$crit:$line -> $dl{$line}\n";
 
-                    # Change key from the MD5 digest to the actual line number.
+                    # Change key from the MD5 digest to the actual line number
                     $c->{$dl{$line}} = delete $c->{$line};
                 } else {
                     warn "Devel::Cover: Can't find line for uncovered data: " .
@@ -585,7 +599,7 @@ sub uncoverable {
                 }
             }
         }
-        # Change the key from the filename to the MD5 digest of the file.
+        # Change the key from the filename to the MD5 digest of the file
         $u->{$df->hexdigest} = delete $u->{$file};
     }
 
@@ -760,7 +774,7 @@ sub objectify_cover {
         *Devel::Cover::DB::File::DESTROY = sub {};
         unless (exists &Devel::Cover::DB::File::AUTOLOAD) {
             *Devel::Cover::DB::File::AUTOLOAD = sub {
-                # Work around a change in bleadperl from 12251 to 14899.
+                # Work around a change in bleadperl from 12251 to 14899
                 my $func = $Devel::Cover::DB::AUTOLOAD || $::AUTOLOAD;
 
                 # print STDERR "autoloading <$func>\n";
@@ -787,8 +801,14 @@ sub cover {
     my $cover = $self->{cover} = {};
     my $uncoverable = {};
     my $st = Devel::Cover::DB::Structure->new(base => $self->{base})->read_all;
-    my @runs = sort { $self->{runs}{$b}{start} <=> $self->{runs}{$a}{start} }
-                    keys %{$self->{runs}};
+    # Sometimes the start value is undefined.  It's not yet clear why, but it
+    # probably has something to do with the code under test forking.  We'll
+    # just try to cope with that here.
+    my @runs = sort {
+        ($self->{runs}{$b}{start} || 0) <=> ($self->{runs}{$a}{start} || 0)
+                                        ||
+                                     $b cmp $a
+    } keys %{$self->{runs}};
     # print STDERR "runs: ", Dumper \@runs
 
     my %warned;
@@ -820,7 +840,12 @@ sub cover {
                 unless $digests{$digest};
 
             # Set up data structure to hold coverage being filled in
-            my $cf = $cover->{$digests{$digest} ||= $file} ||= {};
+            my $ff = $file;
+            if ($self->{prefer_lib}) {
+                $ff =~ s|^blib/||;
+                $ff = $file unless -e $ff;
+            }
+            my $cf = $cover->{$digests{$digest} ||= $ff} ||= {};
 
             # print STDERR "st ", Dumper($st),
                          # "f  ", Dumper($f),
@@ -892,7 +917,7 @@ Devel::Cover::DB - Code coverage metrics for Perl
 
 =head1 VERSION
 
-version 1.21
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -911,7 +936,7 @@ This module provides access to a database of code coverage information.
 
  my $db = Devel::Cover::DB->new(db => "my_coverage_db");
 
-Contructs the DB from the specified database.
+Constructs the DB from the specified database.
 
 =head2 cover
 
@@ -978,7 +1003,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
