@@ -2,7 +2,7 @@ package Devel::Cover::Report::Html_subtle;
 use strict;
 use warnings;
 
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.29'; # VERSION
 
 use Devel::Cover::DB;
 use Devel::Cover::Html_Common "launch";
@@ -115,7 +115,7 @@ sub print_summary {
     my $html = "$options->{outputdir}/$options->{option}{outputfile}";
     $Template->process("summary", $vars, $html) or die $Template->error();
 
-    print "HTML output sent to $html\n";
+    print "HTML output written to $html\n" unless $options->{silent};
 }
 
 
@@ -373,7 +373,6 @@ sub report {
     %File_exists = map {$_ => -e} @{$options->{file}};
 
     print_stylesheet($db);
-    print_summary($db, $options);
 
     for my $file (@{$options->{file}}) {
         print_file($db,        $file, $options);
@@ -381,6 +380,7 @@ sub report {
         print_conditions($db,  $file, $options) if $options->{show}{condition};
         print_subroutines($db, $file, $options) if $options->{show}{subroutine};
     }
+    print_summary($db, $options);
 }
 
 1;
@@ -389,7 +389,7 @@ package Devel::Cover::Report::Html_subtle::Template::Provider;
 use strict;
 use warnings;
 
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.29'; # VERSION
 
 use base "Template::Provider";
 
@@ -408,7 +408,7 @@ $Templates{html} = <<'EOT';
 <?xml version="1.0" encoding="utf-8"?>
 <!--
 This file was generated by Devel::Cover Version $VERSION
-Devel::Cover is copyright 2001-2012, Paul Johnson (paul\@pjcj.net)
+Devel::Cover is copyright 2001-2017, Paul Johnson (paul\@pjcj.net)
 Devel::Cover is free. It is licensed under the same terms as Perl itself.
 The latest version of Devel::Cover should be available from my homepage:
 http://www.pjcj.net
@@ -708,7 +708,7 @@ Devel::Cover::Report::Html_subtle - HTML backend for Devel::Cover
 
 =head1 VERSION
 
-version 1.21
+version 1.29
 
 =head1 SYNOPSIS
 
@@ -732,7 +732,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
