@@ -1,4 +1,4 @@
-# Copyright 2002-2015, Paul Johnson (paul@pjcj.net)
+# Copyright 2002-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,12 +10,12 @@ package Devel::Cover::Test;
 use strict;
 use warnings;
 
-our $VERSION = '1.21'; # VERSION
+our $VERSION = '1.29'; # VERSION
 
 use Carp;
 
 use File::Spec;
-use Test ();
+use Test::More;
 
 use Devel::Cover::Inc;
 
@@ -82,8 +82,7 @@ sub get_params {
                               . "@{$self->{test_parameters}}";
     $self->{criteria}         =~ s/-\w+//g;
     $self->{db_name}        ||= $self->{test};
-    $self->{cover_db}         = "$Devel::Cover::Inc::Base/t/e2e/"
-                              . "cover_db_$self->{db_name}/";
+    $self->{cover_db}         = "./t/e2e/cover_db_$self->{db_name}/";
     unless (mkdir $self->{cover_db}) {
         die "Can't mkdir $self->{cover_db}: $!" unless -d $self->{cover_db};
     }
@@ -111,7 +110,7 @@ sub perl {
     join " ",
          map shell_quote($_),
              $Devel::Cover::Inc::Perl,
-             map "-I$Devel::Cover::Inc::Base/$_", "", "blib/lib", "blib/arch"
+             map "-I./$_", "", "blib/lib", "blib/arch"
 }
 
 sub test_command {
@@ -132,14 +131,13 @@ sub test_command {
 
 sub cover_command {
     my $self = shift;
-    my $b = shell_quote $Devel::Cover::Inc::Base;
-    my $c = $self->perl . " $b/bin/cover $self->{cover_parameters}";
+    my $c = $self->perl . " ./bin/cover $self->{cover_parameters}";
     $c
 }
 
 sub test_file {
     my $self = shift;
-    "$Devel::Cover::Inc::Base/tests/$self->{test}"
+    "./tests/$self->{test}"
 }
 
 sub test_file_parameters {
@@ -152,7 +150,7 @@ sub cover_gold {
 
     my $test = $self->{golden_test} || $self->{test};
 
-    my $td = "$Devel::Cover::Inc::Base/test_output/cover";
+    my $td = "./test_output/cover";
     opendir D, $td or die "Can't opendir $td: $!";
     my @versions = sort    { $a <=> $b }
                    map     { /^$test\.(5\.\d+)$/ ? $1 : () }
@@ -197,23 +195,19 @@ sub run_command {
 sub run_test {
     my $self = shift;
 
+    if ($] < 5.010000) {
+        plan skip_all => "Perl version $] is not supported";
+        return;
+    }
+
     if ($self->{skip}) {
-        Test::plan tests => 1;
-        Test::skip($self->{skip}, 1);
+        plan skip_all => $self->{skip};
         return;
     }
 
     my $version = int(($] - 5) * 1000 + 0.5);
-    if ($version % 2 && $version < 22) {
-        Test::plan tests => 1;
-        Test::skip("Perl version $] is an obsolete development version", 1);
-        return;
-    }
-
-    if ($] > 5.019001 && $] < 5.019004) {
-        Test::plan tests => 1;
-        Test::skip("Perl version $] contains a bug which causes this test " .
-                   "to fail", 1);
+    if ($version % 2 && $version < 26) {
+        plan skip_all => "Perl version $] is an obsolete development version";
         return;
     }
 
@@ -229,11 +223,11 @@ sub run_test {
 
     # print STDERR "gold from $gold\n", @cover if $self->{debug};
 
-    Test::plan tests => $self->{differences}
-                            ? 1
-                            : exists $self->{tests}
-                                  ? $self->{tests}->(scalar @cover)
-                                  : scalar @cover;
+    plan tests => $self->{differences}
+        ? 1
+        : exists $self->{tests}
+            ? $self->{tests}->(scalar @cover)
+            : scalar @cover;
 
     local $ENV{PERL5OPT};
     $self->{run_test}
@@ -302,16 +296,16 @@ sub run_cover {
             push @at, $t;
             push @ac, $c;
         } else {
-            $self->{no_coverage} ? Test::ok 1 : Test::ok $t, $c;
+            $self->{no_coverage} ? pass : is($t, $c);
             last if $self->{no_coverage} && !@{$self->{cover}};
         }
     }
     if ($self->{differences}) {
         no warnings "redefine";
         local *Test::_quote = sub { "@_" };
-        $self->{no_coverage} ? Test::ok 1 : eq_or_diff(\@at, \@ac, "output");
+        $self->{no_coverage} ? pass : eq_or_diff(\@at, \@ac, "output");
     } elsif ($self->{no_coverage}) {
-        Test::ok 1 for @{$self->{cover}};
+        pass for @{$self->{cover}};
     }
     close T or die "Cannot close $cover_com: $!";
 
@@ -322,10 +316,8 @@ sub create_gold {
     my $self = shift;
 
     # Pod::Coverage not available on all versions, but it must be there on
-    # 5.6.1 and 5.8.0
-    return if $self->{criteria} =~ /\bpod\b/ &&
-               $] != 5.006001 &&
-               $] != 5.008000;
+    # 5.10.0
+    return if $self->{criteria} =~ /\bpod\b/ && $] != 5.010000;
 
     my ($base, $v) = $self->cover_gold;
     my $gold       = "$base.$v";
@@ -398,7 +390,7 @@ Devel::Cover::Test - Internal module for testing
 
 =head1 VERSION
 
-version 1.21
+version 1.29
 
 =head1 METHODS
 
@@ -497,7 +489,7 @@ Huh?
 
 =head1 LICENCE
 
-Copyright 2001-2015, Paul Johnson (paul@pjcj.net)
+Copyright 2001-2017, Paul Johnson (paul@pjcj.net)
 
 This software is free.  It is licensed under the same terms as Perl itself.
 
