@@ -1,4 +1,4 @@
-# Copyright 2002-2013, Paul Johnson (paul@pjcj.net)
+# Copyright 2002-2017, Paul Johnson (paul@pjcj.net)
 
 # This software is free.  It is licensed under the same terms as Perl itself.
 
@@ -10,26 +10,22 @@ package NotModule2;
 my $y = 7;
 $y++;
 
-sub _aa
-{
+sub _aa {
     $y++;
     die;
     die;
 }
 
-sub _xx
-{
+sub _xx {
     $y++;
     die;
 }
 
-sub yy
-{
+sub yy {
     $y++;
 }
 
-sub zz
-{
+sub zz {
     my $x = shift;
     $x++;
 }
